@@ -1,6 +1,6 @@
 #!python3
 
-from pathlib import Path
+from pathlib import Path, WindowsPath
 import gpxutils
 
 
@@ -18,6 +18,13 @@ def processFiles(gpxDir, **options):
 def gpxpull(drive, **options):
     gpxutils.applyDefaults(options)
 
+    # Hack to create proper absolute drive paths on Windows
+    if not drive.is_absolute() and isinstance(drive, WindowsPath):
+        if len(str(drive)) == 1:
+            drive = Path(str(drive) + ':/')
+        elif len(str(drive)) == 2 and str(drive)[1] == ':':
+            drive /= '/'
+
     gpxDir = drive / 'Garmin' / 'GPX'
     if gpxDir.exists():
         processFiles(gpxDir, **options)
@@ -31,7 +38,7 @@ def main():
 
     if args.pause:
         import atexit
-        atexit.register(lambda: input('\nPress ENTER to exit...'))
+        atexit.register(lambda: input('\n[Press ENTER to exit]'))
 
     if args.prefix == str():
         args.prefix = input('File prefix: ')
